contexttools.ClefMark
=====================

.. inheritance-diagram:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark
   :private-bases:

.. autoclass:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.effective_context

   .. note:: Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

.. autoattribute:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.format

.. autoattribute:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.middle_c_position

.. autoattribute:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.start_component

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. autoattribute:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.target_context

   .. note:: Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.clef_name

Methods
-------

.. automethod:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.attach

   .. note:: Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

.. automethod:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.detach

   .. note:: Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

Special Methods
---------------

.. automethod:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.__call__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.__delattr__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.__eq__

.. automethod:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.__ne__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.__repr__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.contexttools.ClefMark.ClefMark.ClefMark.__str__

   .. note:: Inherited from `__builtin__.object`
